@@ -1,5 +1,5 @@
 """init pyezviz."""
-from pyezviz.camera import EzvizCamera
+from pyezviz.camera import EzvizCamera  # pylint: disable=unused-import
 from pyezviz.client import EzvizClient, PyEzvizError
 from pyezviz.constants import (DefenseModeType, DeviceCatagories,
                                DeviceSwitchType, SoundMode)
